import { defineStore } from 'pinia'
import { store } from '../index'
import { useStorage } from '@/hooks/web/useStorage'
import { CrudSchema } from '@/hooks/web/useCrudSchemas'

interface PageDataTypes {
  schemas?: CrudSchema[]
  search?: Object
}

interface PageDataTypesList {
  [key: string]: PageDataTypes
}

const { setStorage } = useStorage('localStorage')

interface AppState {
  pageData: PageDataTypesList
}

export const usePageStore = defineStore('page', {
  state: (): AppState => {
    return {
      pageData: {}
    }
  },
  getters: {
    getPageData(): PageDataTypes {
      return this.pageData
    }
  },
  actions: {
    setPageData(page: string, data: PageDataTypes) {
      this.pageData[page] = data
      setStorage('pageData', this.pageData)
    },
    setAllPageData(data: PageDataTypesList) {
      this.pageData = data
    }
  }
})

export const usePageStoreWithOut = () => {
  return usePageStore(store)
}
